Module lexer

Module lexer 

Lexer for the Markdown syntax.

This module contains the lexer for the Markdown syntax. At this stage, the text is joined and non-breakable spaces are removed.

Functions

lex
Split a string into tokens.